<?php

namespace Drupal\view_custom_table\Form;

use Drupal\Component\Utility\UrlHelper;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Edit views custom table form.
 */
class EditViewsCustomTable extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'view_custom_table_edit_table_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $table_name = NULL) {
    $query = \Drupal::database()->select('custom_table_view_data', 'vd')
      ->fields('vd', [
        'description',
      ])
      ->condition('table_name', $table_name);
    $default_description = $query->execute()->fetchField();
    $form['table_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Table'),
      '#default_value' => $table_name,
      '#disabled' => TRUE,
      '#required' => TRUE,
    ];
    $form['description'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Description'),
      '#default_value' => ($default_description != NULL) ? $default_description : '',
      '#rows' => 5,
      '#description' => $this->t('Maximum 255 letters are allowed.'),
    ];

    $form['actions'] = [
      '#type' => 'actions',
    ];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];
    $form['actions']['cancel'] = [
      '#type' => 'link',
      '#title' => $this->t('Cancel'),
      '#url' => $this->buildCancelLinkUrl(),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $description = $form_state->getValue('description');
    if (strlen($description) > 254) {
      $form_state->setErrorByName('description', $this->t("Description can not be more then 255 letters. Please update it and try again."));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $table_name = $form_state->getValue('table_name');
    $description = $form_state->getValue('description');
    $result = \Drupal::database()->update('custom_table_view_data')
      ->fields([
        'description' => $description,
      ])
      ->condition('table_name', $table_name)
      ->execute();
    if ($result) {
      drupal_set_message($this->t('@table is updated.', [
        '@table' => $table_name,
      ]));
    }
    else {
      drupal_set_message($this->t('Could not update @table data, please check log messages for error.', [
        '@table' => $table_name,
      ]), 'error');
    }
    $form_state->setRedirect('view_custom_table.customtable');
  }

  /**
   * Builds the cancel link url for the form.
   *
   * @return Drupal\Core\Url
   *   Cancel url
   */
  private function buildCancelLinkUrl() {
    $query = $this->getRequest()->query;

    if ($query->has('destination')) {
      $options = UrlHelper::parse($query->get('destination'));
      $url = Url::fromUri('internal:/' . $options['path'], $options);
    }
    else {
      $url = Url::fromRoute('view_custom_table.customtable');
    }

    return $url;
  }

}
